@@ -13,7 +13,7 @@
 #' @param nFolds The number of folds for cross-validation.
 #' @param seed The seed used in randomly shuffling the data for cross-validation.
 #' @param kFolds The number of folds for sample split.
-#' @param rThreshold rThreshold.
+#' @param rThreshold Threshold of R^2.
 #' @param regulators Regulator genes.
 #' @param targets Target genes.
 #' @param maxSuppSize The number of non-zore coef, this value will affect the final performance.
@@ -21,6 +21,7 @@
 #' Recommend setting this to a small fraction of min(n,p) (e.g. 0.05 * min(n,p)) as L0 regularization typically selects a small portion of non-zeros.
 #' @param verbose Print detailed information.
 #' @param cores CPU cores.
+#' @param ... Arguments passed to other methods.
 #'
 #' @import Matrix
 #'
@@ -48,19 +49,7 @@
 #'
 setGeneric("inferCSN",
            signature = "matrix",
-           function(matrix,
-                    penalty = "L0",
-                    algorithm = "CD",
-                    crossValidation = FALSE,
-                    seed = 1,
-                    nFolds = 10,
-                    kFolds = NULL,
-                    rThreshold = 0,
-                    regulators = NULL,
-                    targets = NULL,
-                    maxSuppSize = NULL,
-                    verbose = FALSE,
-                    cores = 1) {
+           function(matrix, ...) {
              UseMethod(generic = "inferCSN", object = matrix)
            })
 
@@ -81,7 +70,8 @@ setMethod("inferCSN",
                    targets = NULL,
                    maxSuppSize = NULL,
                    verbose = FALSE,
-                   cores = 1) {
+                   cores = 1,
+                   ...) {
             warning("Converting the class type of input data from <data.frame> to <matrix>.")
             matrix <- as.matrix(matrix)
             .inferCSN(matrix = matrix,
@@ -116,7 +106,8 @@ setMethod("inferCSN",
                    targets = NULL,
                    maxSuppSize = NULL,
                    verbose = FALSE,
-                   cores = 1) {
+                   cores = 1,
+                   ...) {
             .inferCSN(matrix = matrix,
                       penalty = penalty,
                       algorithm = algorithm,
@@ -144,8 +135,9 @@ setMethod("inferCSN",
                       targets,
                       maxSuppSize,
                       verbose,
-                      cores) {
-  if(verbose) message("Runing start.")
+                      cores,
+                      ...) {
+  if(verbose) message("Running start.")
 
   # Check input parameters
   check.parameters(matrix = matrix,
@@ -167,7 +159,6 @@ setMethod("inferCSN",
   } else {
     regulatorsMatrix <- matrix
   }
-  regulators <- colnames(regulatorsMatrix)
 
   if (!is.null(targets)) {
     targetsMatrix <- matrix[, intersect(colnames(matrix), targets)]
@@ -183,11 +174,11 @@ setMethod("inferCSN",
     # Format progress information
     format <- "Running [:bar] :percent, No.:current of :total genes, :elapsed."
     pb <- progress::progress_bar$new(format = format,
-                                     total = length(regulators),
+                                     total = length(targets),
                                      clear = TRUE,
                                      width = 80)
 
-    weightDT <- purrr::map_dfr(regulators, function(x) {
+    weightDT <- purrr::map_dfr(targets, function(x) {
       if (verbose) pb$tick()
       sub.inferCSN(regulatorsMatrix = regulatorsMatrix,
                    targetsMatrix = targetsMatrix,
